package us.jakest.desker

import android.content.Intent
import android.content.pm.ResolveInfo
import android.os.Bundle
import android.widget.Space
import androidx.activity.ComponentActivity
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.StaggeredGridLayoutManager

class MainActivity : ComponentActivity() {
    private lateinit var resolvedAppList: List<ResolveInfo>

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        resolvedAppList = packageManager
            .queryIntentActivities(Intent(Intent.ACTION_MAIN, null)
                .addCategory(Intent.CATEGORY_LAUNCHER), 0)
        val appList = ArrayList<AppBlock>()

        for (ri in resolvedAppList) {
            if(ri.activityInfo.packageName != this.packageName) {
                val app = AppBlock(
                    name = ri.loadLabel(packageManager).toString(),
                    icon = ri.loadIcon(packageManager),
                    packageName = ri.activityInfo.packageName
                )
                appList.add(app)
            }
        }

        setContentView(R.layout.activity_main)
        val adapter = Adapter(appList.sortedWith { o1, o2 ->
            o1?.name?.compareTo(
                o2?.name ?: "",
                true
            ) ?: 0
        })
        val rView = findViewById<RecyclerView>(R.id.appList)
        rView.layoutManager = StaggeredGridLayoutManager(1, LinearLayoutManager.VERTICAL)
        rView.adapter = adapter

        updateBottomPadding()
    }

    private fun updateBottomPadding() {
        val endPadding = findViewById<Space>(R.id.loppuTyhjyys)
        val navBarHeight =
            resources.getDimensionPixelSize(
                resources.getIdentifier("navigation_bar_height", "dimen", "android")
            )
        /*
        val statusBarHeight =
            resources.getDimensionPixelSize(
                resources.getIdentifier("status_bar_height", "dimen", "android")
            )
         */
        endPadding.layoutParams.height = navBarHeight
    }
}

